@@ -13,11 +13,11 @@ Getopt::Long::Descriptive - Getopt::Long with usage text
 
 =head1 VERSION
 
-Version 0.073
+Version 0.074
 
 =cut
 
-our $VERSION = '0.073';
+our $VERSION = '0.074';
 
 =head1 DESCRIPTION
 
@@ -242,7 +242,7 @@ sub _expand {
     spec       => $_->[0] || '',
     desc       => @$_ > 1 ? $_->[1] : 'spacer',
     constraint => $_->[2] || {},
-    name       => _munge((split /[=|!]/, $_->[0] || '')[0]),
+    name       => _munge((split /[:=|!]/, $_->[0] || '')[0]),
   )} } @_;
 }
     
